@@ -178,7 +178,7 @@ class PagesManagerGenericChild(SignalsHelper, GesturesHelper):
             self.__background_image.set_from_surface(None)
             self.__indicator_image.set_from_surface(None)
             self.__indicator_image.set_from_icon_name(
-                "emblem-synchronizing-symbolic", Gtk.IconSize.DND)
+                "network-transmit-receive-symbolic", Gtk.IconSize.DND)
             self.__indicator_image.get_style_context().add_class(
                 "image-rotate")
             self.__indicator_image.show()
