@@ -1,4 +1,4 @@
-# Copyright (c) 2017-2020 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
+# Copyright (c) 2017-2021 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
@@ -15,7 +15,7 @@ from gi.repository import WebKit2, Gio, GLib
 from urllib.parse import urlparse
 from time import time
 
-from eolie.define import App, LoadingType
+from eolie.define import App, LoadingType, LoadingState
 from eolie.context import Context
 from eolie.webview_errors import WebViewErrors
 from eolie.webview_navigation import WebViewNavigation
@@ -26,6 +26,7 @@ from eolie.webview_credentials import WebViewCredentials
 from eolie.webview_helpers import WebViewHelpers
 from eolie.webview_night_mode import WebViewNightMode
 from eolie.list import LinkedList
+from eolie.utils import emit_signal
 from eolie.logger import Logger
 
 
@@ -108,6 +109,27 @@ class WebView(WebKit2.WebView):
         Logger.debug("Update zoom level: %s", zoom_level)
         self.set_zoom_level(zoom_level)
 
+    def is_playing_audio(self):
+        """
+            Do not return True if sound disabled
+        """
+        value = App().websettings.get("audio", self.uri)
+        if value:
+            return WebKit2.WebView.is_playing_audio(self)
+        else:
+            return False
+
+    def update_sound_policy(self):
+        """
+            Update sound policy
+        """
+        value = App().websettings.get("audio", self.uri)
+        self.__window.container.webview.set_is_muted(not value)
+        if value:
+            emit_signal(self, "is-playing-audio", self.is_playing_audio())
+        else:
+            emit_signal(self, "is-playing-audio", False)
+
     def print(self):
         """
             Show print dialog for current page
@@ -295,16 +317,16 @@ class WebView(WebKit2.WebView):
         """
             Stop loading webview
         """
-        self._loading = False
+        self._loading_state = LoadingState.STOPPED
         WebKit2.WebView.stop_loading(self)
 
     @property
-    def readability(self):
+    def loading_state(self):
         """
-            True if webview readable
-            @return bool
+            Get loading state
+            @return LoadingState
         """
-        return self._readability
+        return self._loading_state
 
     @property
     def atime(self):
@@ -391,10 +413,9 @@ class WebView(WebKit2.WebView):
         WebViewCredentials.__init__(self)
         self.__window = window
         self.__atime = 0
-        self._loading = False
+        self._loading_state = LoadingState.NONE
         self.__children = []
         self.__parent = None
-        self._readability = False
         self._title = None
         self.__related = related
         self.__shown = False
@@ -463,6 +484,8 @@ class WebView(WebKit2.WebView):
                     "enable-back-forward-navigation-gestures", True)
         self.connect("create", self.__on_create)
         self.connect("load-changed", self._on_load_changed)
+        self.connect("notify::is-playing-audio",
+                     self.__on_notify_is_playing_audio)
         self.connect("destroy", self.__on_destroy)
 
     def __set_system_fonts(self, settings):
@@ -530,6 +553,18 @@ class WebView(WebKit2.WebView):
         for child in self.__children:
             child.disconnect_by_func(self.__on_child_destroy)
 
+    def __on_notify_is_playing_audio(self, webview, param):
+        """
+            Send custom signal
+            @param webview as WebView
+            @param param as GParam
+        """
+        value = App().websettings.get("audio", self.uri)
+        if value:
+            emit_signal(self, "is-playing-audio", self.is_playing_audio())
+        else:
+            emit_signal(self, "is-playing-audio", False)
+
     def __on_child_destroy(self, webview):
         """
             Remove from children
